@@ -10,12 +10,37 @@ Usage::
     client: WorkDocsClient = boto3.client("workdocs")
     ```
 """
-import sys
 from datetime import datetime
 from typing import Any, Dict, List, Type, overload
 
 from botocore.client import ClientMeta
 
+from mypy_boto3_workdocs.literals import (
+    BooleanEnumType,
+    CommentVisibilityType,
+    DescribeActivitiesPaginatorName,
+    DescribeCommentsPaginatorName,
+    DescribeDocumentVersionsPaginatorName,
+    DescribeFolderContentsPaginatorName,
+    DescribeGroupsPaginatorName,
+    DescribeNotificationSubscriptionsPaginatorName,
+    DescribeResourcePermissionsPaginatorName,
+    DescribeRootFoldersPaginatorName,
+    DescribeUsersPaginatorName,
+    DocumentVersionStatus,
+    FolderContentType,
+    LocaleType,
+    OrderType,
+    PrincipalType,
+    ResourceCollectionType,
+    ResourceSortType,
+    ResourceStateType,
+    SubscriptionProtocolType,
+    SubscriptionType,
+    UserFilterType,
+    UserSortType,
+    UserType,
+)
 from mypy_boto3_workdocs.paginator import (
     DescribeActivitiesPaginator,
     DescribeCommentsPaginator,
@@ -57,12 +82,6 @@ from mypy_boto3_workdocs.type_defs import (
     UpdateUserResponseTypeDef,
 )
 
-if sys.version_info >= (3, 8):
-    from typing import Literal
-else:
-    from typing_extensions import Literal
-
-
 __all__ = ("WorkDocsClient",)
 
 
@@ -149,7 +168,7 @@ class WorkDocsClient:
         AuthenticationToken: str = None,
         ParentId: str = None,
         ThreadId: str = None,
-        Visibility: Literal["PUBLIC", "PRIVATE"] = None,
+        Visibility: CommentVisibilityType = None,
         NotifyCollaborators: bool = None,
     ) -> CreateCommentResponseTypeDef:
         """
@@ -185,8 +204,8 @@ class WorkDocsClient:
         self,
         OrganizationId: str,
         Endpoint: str,
-        Protocol: Literal["HTTPS"],
-        SubscriptionType: Literal["ALL"],
+        Protocol: SubscriptionProtocolType,
+        SubscriptionType: SubscriptionType,
     ) -> CreateNotificationSubscriptionResponseTypeDef:
         """
         [Client.create_notification_subscription documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.60/reference/services/workdocs.html#WorkDocs.Client.create_notification_subscription)
@@ -314,11 +333,11 @@ class WorkDocsClient:
         self,
         FolderId: str,
         AuthenticationToken: str = None,
-        Sort: Literal["DATE", "NAME"] = None,
-        Order: Literal["ASCENDING", "DESCENDING"] = None,
+        Sort: ResourceSortType = None,
+        Order: OrderType = None,
         Limit: int = None,
         Marker: str = None,
-        Type: Literal["ALL", "DOCUMENT", "FOLDER"] = None,
+        Type: FolderContentType = None,
         Include: str = None,
     ) -> DescribeFolderContentsResponseTypeDef:
         """
@@ -369,11 +388,9 @@ class WorkDocsClient:
         OrganizationId: str = None,
         UserIds: str = None,
         Query: str = None,
-        Include: Literal["ALL", "ACTIVE_PENDING"] = None,
-        Order: Literal["ASCENDING", "DESCENDING"] = None,
-        Sort: Literal[
-            "USER_NAME", "FULL_NAME", "STORAGE_LIMIT", "USER_STATUS", "STORAGE_USED"
-        ] = None,
+        Include: UserFilterType = None,
+        Order: OrderType = None,
+        Sort: UserSortType = None,
         Marker: str = None,
         Limit: int = None,
         Fields: str = None,
@@ -452,7 +469,7 @@ class WorkDocsClient:
         self,
         AuthenticationToken: str = None,
         UserId: str = None,
-        CollectionType: Literal["SHARED_WITH_ME"] = None,
+        CollectionType: ResourceCollectionType = None,
         Limit: int = None,
         Marker: str = None,
     ) -> GetResourcesResponseTypeDef:
@@ -487,7 +504,7 @@ class WorkDocsClient:
         ResourceId: str,
         PrincipalId: str,
         AuthenticationToken: str = None,
-        PrincipalType: Literal["USER", "GROUP", "INVITE", "ANONYMOUS", "ORGANIZATION"] = None,
+        PrincipalType: PrincipalType = None,
     ) -> None:
         """
         [Client.remove_resource_permission documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.60/reference/services/workdocs.html#WorkDocs.Client.remove_resource_permission)
@@ -499,7 +516,7 @@ class WorkDocsClient:
         AuthenticationToken: str = None,
         Name: str = None,
         ParentFolderId: str = None,
-        ResourceState: Literal["ACTIVE", "RESTORING", "RECYCLING", "RECYCLED"] = None,
+        ResourceState: ResourceStateType = None,
     ) -> None:
         """
         [Client.update_document documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.60/reference/services/workdocs.html#WorkDocs.Client.update_document)
@@ -510,7 +527,7 @@ class WorkDocsClient:
         DocumentId: str,
         VersionId: str,
         AuthenticationToken: str = None,
-        VersionStatus: Literal["ACTIVE"] = None,
+        VersionStatus: DocumentVersionStatus = None,
     ) -> None:
         """
         [Client.update_document_version documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.60/reference/services/workdocs.html#WorkDocs.Client.update_document_version)
@@ -522,7 +539,7 @@ class WorkDocsClient:
         AuthenticationToken: str = None,
         Name: str = None,
         ParentFolderId: str = None,
-        ResourceState: Literal["ACTIVE", "RESTORING", "RECYCLING", "RECYCLED"] = None,
+        ResourceState: ResourceStateType = None,
     ) -> None:
         """
         [Client.update_folder documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.60/reference/services/workdocs.html#WorkDocs.Client.update_folder)
@@ -534,13 +551,11 @@ class WorkDocsClient:
         AuthenticationToken: str = None,
         GivenName: str = None,
         Surname: str = None,
-        Type: Literal["USER", "ADMIN", "POWERUSER", "MINIMALUSER", "WORKSPACESUSER"] = None,
+        Type: UserType = None,
         StorageRule: "StorageRuleTypeTypeDef" = None,
         TimeZoneId: str = None,
-        Locale: Literal[
-            "en", "fr", "ko", "de", "es", "ja", "ru", "zh_CN", "zh_TW", "pt_BR", "default"
-        ] = None,
-        GrantPoweruserPrivileges: Literal["TRUE", "FALSE"] = None,
+        Locale: LocaleType = None,
+        GrantPoweruserPrivileges: BooleanEnumType = None,
     ) -> UpdateUserResponseTypeDef:
         """
         [Client.update_user documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.60/reference/services/workdocs.html#WorkDocs.Client.update_user)
@@ -548,7 +563,7 @@ class WorkDocsClient:
 
     @overload
     def get_paginator(
-        self, operation_name: Literal["describe_activities"]
+        self, operation_name: DescribeActivitiesPaginatorName
     ) -> DescribeActivitiesPaginator:
         """
         [Paginator.DescribeActivities documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.60/reference/services/workdocs.html#WorkDocs.Paginator.DescribeActivities)
@@ -556,7 +571,7 @@ class WorkDocsClient:
 
     @overload
     def get_paginator(
-        self, operation_name: Literal["describe_comments"]
+        self, operation_name: DescribeCommentsPaginatorName
     ) -> DescribeCommentsPaginator:
         """
         [Paginator.DescribeComments documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.60/reference/services/workdocs.html#WorkDocs.Paginator.DescribeComments)
@@ -564,7 +579,7 @@ class WorkDocsClient:
 
     @overload
     def get_paginator(
-        self, operation_name: Literal["describe_document_versions"]
+        self, operation_name: DescribeDocumentVersionsPaginatorName
     ) -> DescribeDocumentVersionsPaginator:
         """
         [Paginator.DescribeDocumentVersions documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.60/reference/services/workdocs.html#WorkDocs.Paginator.DescribeDocumentVersions)
@@ -572,21 +587,21 @@ class WorkDocsClient:
 
     @overload
     def get_paginator(
-        self, operation_name: Literal["describe_folder_contents"]
+        self, operation_name: DescribeFolderContentsPaginatorName
     ) -> DescribeFolderContentsPaginator:
         """
         [Paginator.DescribeFolderContents documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.60/reference/services/workdocs.html#WorkDocs.Paginator.DescribeFolderContents)
         """
 
     @overload
-    def get_paginator(self, operation_name: Literal["describe_groups"]) -> DescribeGroupsPaginator:
+    def get_paginator(self, operation_name: DescribeGroupsPaginatorName) -> DescribeGroupsPaginator:
         """
         [Paginator.DescribeGroups documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.60/reference/services/workdocs.html#WorkDocs.Paginator.DescribeGroups)
         """
 
     @overload
     def get_paginator(
-        self, operation_name: Literal["describe_notification_subscriptions"]
+        self, operation_name: DescribeNotificationSubscriptionsPaginatorName
     ) -> DescribeNotificationSubscriptionsPaginator:
         """
         [Paginator.DescribeNotificationSubscriptions documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.60/reference/services/workdocs.html#WorkDocs.Paginator.DescribeNotificationSubscriptions)
@@ -594,7 +609,7 @@ class WorkDocsClient:
 
     @overload
     def get_paginator(
-        self, operation_name: Literal["describe_resource_permissions"]
+        self, operation_name: DescribeResourcePermissionsPaginatorName
     ) -> DescribeResourcePermissionsPaginator:
         """
         [Paginator.DescribeResourcePermissions documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.60/reference/services/workdocs.html#WorkDocs.Paginator.DescribeResourcePermissions)
@@ -602,14 +617,14 @@ class WorkDocsClient:
 
     @overload
     def get_paginator(
-        self, operation_name: Literal["describe_root_folders"]
+        self, operation_name: DescribeRootFoldersPaginatorName
     ) -> DescribeRootFoldersPaginator:
         """
         [Paginator.DescribeRootFolders documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.60/reference/services/workdocs.html#WorkDocs.Paginator.DescribeRootFolders)
         """
 
     @overload
-    def get_paginator(self, operation_name: Literal["describe_users"]) -> DescribeUsersPaginator:
+    def get_paginator(self, operation_name: DescribeUsersPaginatorName) -> DescribeUsersPaginator:
         """
         [Paginator.DescribeUsers documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.60/reference/services/workdocs.html#WorkDocs.Paginator.DescribeUsers)
         """
