@@ -32,12 +32,18 @@ Usage::
     describe_users_paginator: DescribeUsersPaginator = client.get_paginator("describe_users")
     ```
 """
-import sys
 from datetime import datetime
 from typing import Iterator
 
 from botocore.paginate import Paginator as Boto3Paginator
 
+from mypy_boto3_workdocs.literals import (
+    FolderContentType,
+    OrderType,
+    ResourceSortType,
+    UserFilterType,
+    UserSortType,
+)
 from mypy_boto3_workdocs.type_defs import (
     DescribeActivitiesResponseTypeDef,
     DescribeCommentsResponseTypeDef,
@@ -51,12 +57,6 @@ from mypy_boto3_workdocs.type_defs import (
     PaginatorConfigTypeDef,
 )
 
-if sys.version_info >= (3, 8):
-    from typing import Literal
-else:
-    from typing_extensions import Literal
-
-
 __all__ = (
     "DescribeActivitiesPaginator",
     "DescribeCommentsPaginator",
@@ -136,9 +136,9 @@ class DescribeFolderContentsPaginator(Boto3Paginator):
         self,
         FolderId: str,
         AuthenticationToken: str = None,
-        Sort: Literal["DATE", "NAME"] = None,
-        Order: Literal["ASCENDING", "DESCENDING"] = None,
-        Type: Literal["ALL", "DOCUMENT", "FOLDER"] = None,
+        Sort: ResourceSortType = None,
+        Order: OrderType = None,
+        Type: FolderContentType = None,
         Include: str = None,
         PaginationConfig: PaginatorConfigTypeDef = None,
     ) -> Iterator[DescribeFolderContentsResponseTypeDef]:
@@ -218,11 +218,9 @@ class DescribeUsersPaginator(Boto3Paginator):
         OrganizationId: str = None,
         UserIds: str = None,
         Query: str = None,
-        Include: Literal["ALL", "ACTIVE_PENDING"] = None,
-        Order: Literal["ASCENDING", "DESCENDING"] = None,
-        Sort: Literal[
-            "USER_NAME", "FULL_NAME", "STORAGE_LIMIT", "USER_STATUS", "STORAGE_USED"
-        ] = None,
+        Include: UserFilterType = None,
+        Order: OrderType = None,
+        Sort: UserSortType = None,
         Fields: str = None,
         PaginationConfig: PaginatorConfigTypeDef = None,
     ) -> Iterator[DescribeUsersResponseTypeDef]:
