@@ -13,10 +13,26 @@ import sys
 from datetime import datetime
 from typing import Dict, List
 
-if sys.version_info >= (3, 8):
-    from typing import Literal
-else:
-    from typing_extensions import Literal
+from mypy_boto3_workdocs.literals import (
+    ActivityType,
+    CommentStatusType,
+    CommentVisibilityType,
+    DocumentSourceType,
+    DocumentStatusType,
+    DocumentThumbnailType,
+    LocaleType,
+    PrincipalType,
+    ResourceStateType,
+    ResourceType,
+    RolePermissionType,
+    RoleType,
+    ShareStatusType,
+    StorageType,
+    SubscriptionProtocolType,
+    UserStatusType,
+    UserType,
+)
+
 if sys.version_info >= (3, 8):
     from typing import TypedDict
 else:
@@ -76,41 +92,7 @@ __all__ = (
 ActivityTypeDef = TypedDict(
     "ActivityTypeDef",
     {
-        "Type": Literal[
-            "DOCUMENT_CHECKED_IN",
-            "DOCUMENT_CHECKED_OUT",
-            "DOCUMENT_RENAMED",
-            "DOCUMENT_VERSION_UPLOADED",
-            "DOCUMENT_VERSION_DELETED",
-            "DOCUMENT_VERSION_VIEWED",
-            "DOCUMENT_VERSION_DOWNLOADED",
-            "DOCUMENT_RECYCLED",
-            "DOCUMENT_RESTORED",
-            "DOCUMENT_REVERTED",
-            "DOCUMENT_SHARED",
-            "DOCUMENT_UNSHARED",
-            "DOCUMENT_SHARE_PERMISSION_CHANGED",
-            "DOCUMENT_SHAREABLE_LINK_CREATED",
-            "DOCUMENT_SHAREABLE_LINK_REMOVED",
-            "DOCUMENT_SHAREABLE_LINK_PERMISSION_CHANGED",
-            "DOCUMENT_MOVED",
-            "DOCUMENT_COMMENT_ADDED",
-            "DOCUMENT_COMMENT_DELETED",
-            "DOCUMENT_ANNOTATION_ADDED",
-            "DOCUMENT_ANNOTATION_DELETED",
-            "FOLDER_CREATED",
-            "FOLDER_DELETED",
-            "FOLDER_RENAMED",
-            "FOLDER_RECYCLED",
-            "FOLDER_RESTORED",
-            "FOLDER_SHARED",
-            "FOLDER_UNSHARED",
-            "FOLDER_SHARE_PERMISSION_CHANGED",
-            "FOLDER_SHAREABLE_LINK_CREATED",
-            "FOLDER_SHAREABLE_LINK_REMOVED",
-            "FOLDER_SHAREABLE_LINK_PERMISSION_CHANGED",
-            "FOLDER_MOVED",
-        ],
+        "Type": ActivityType,
         "TimeStamp": datetime,
         "IsIndirectActivity": bool,
         "OrganizationId": str,
@@ -129,7 +111,7 @@ CommentMetadataTypeDef = TypedDict(
         "CommentId": str,
         "Contributor": "UserTypeDef",
         "CreatedTimestamp": datetime,
-        "CommentStatus": Literal["DRAFT", "PUBLISHED", "DELETED"],
+        "CommentStatus": CommentStatusType,
         "RecipientId": str,
     },
     total=False,
@@ -144,8 +126,8 @@ _OptionalCommentTypeDef = TypedDict(
         "Text": str,
         "Contributor": "UserTypeDef",
         "CreatedTimestamp": datetime,
-        "Status": Literal["DRAFT", "PUBLISHED", "DELETED"],
-        "Visibility": Literal["PUBLIC", "PRIVATE"],
+        "Status": CommentStatusType,
+        "Visibility": CommentVisibilityType,
         "RecipientId": str,
     },
     total=False,
@@ -165,7 +147,7 @@ DocumentMetadataTypeDef = TypedDict(
         "CreatedTimestamp": datetime,
         "ModifiedTimestamp": datetime,
         "LatestVersionMetadata": "DocumentVersionMetadataTypeDef",
-        "ResourceState": Literal["ACTIVE", "RESTORING", "RECYCLING", "RECYCLED"],
+        "ResourceState": ResourceStateType,
         "Labels": List[str],
     },
     total=False,
@@ -179,14 +161,14 @@ DocumentVersionMetadataTypeDef = TypedDict(
         "ContentType": str,
         "Size": int,
         "Signature": str,
-        "Status": Literal["INITIALIZED", "ACTIVE"],
+        "Status": DocumentStatusType,
         "CreatedTimestamp": datetime,
         "ModifiedTimestamp": datetime,
         "ContentCreatedTimestamp": datetime,
         "ContentModifiedTimestamp": datetime,
         "CreatorId": str,
-        "Thumbnail": Dict[Literal["SMALL", "SMALL_HQ", "LARGE"], str],
-        "Source": Dict[Literal["ORIGINAL", "WITH_COMMENTS"], str],
+        "Thumbnail": Dict[DocumentThumbnailType, str],
+        "Source": Dict[DocumentSourceType, str],
     },
     total=False,
 )
@@ -200,7 +182,7 @@ FolderMetadataTypeDef = TypedDict(
         "ParentFolderId": str,
         "CreatedTimestamp": datetime,
         "ModifiedTimestamp": datetime,
-        "ResourceState": Literal["ACTIVE", "RESTORING", "RECYCLING", "RECYCLED"],
+        "ResourceState": ResourceStateType,
         "Signature": str,
         "Labels": List[str],
         "Size": int,
@@ -218,28 +200,19 @@ ParticipantsTypeDef = TypedDict(
 )
 
 PermissionInfoTypeDef = TypedDict(
-    "PermissionInfoTypeDef",
-    {
-        "Role": Literal["VIEWER", "CONTRIBUTOR", "OWNER", "COOWNER"],
-        "Type": Literal["DIRECT", "INHERITED"],
-    },
-    total=False,
+    "PermissionInfoTypeDef", {"Role": RoleType, "Type": RolePermissionType}, total=False
 )
 
 PrincipalTypeDef = TypedDict(
     "PrincipalTypeDef",
-    {
-        "Id": str,
-        "Type": Literal["USER", "GROUP", "INVITE", "ANONYMOUS", "ORGANIZATION"],
-        "Roles": List["PermissionInfoTypeDef"],
-    },
+    {"Id": str, "Type": PrincipalType, "Roles": List["PermissionInfoTypeDef"]},
     total=False,
 )
 
 ResourceMetadataTypeDef = TypedDict(
     "ResourceMetadataTypeDef",
     {
-        "Type": Literal["FOLDER", "DOCUMENT"],
+        "Type": ResourceType,
         "Name": str,
         "OriginalName": str,
         "Id": str,
@@ -263,8 +236,8 @@ ShareResultTypeDef = TypedDict(
     {
         "PrincipalId": str,
         "InviteePrincipalId": str,
-        "Role": Literal["VIEWER", "CONTRIBUTOR", "OWNER", "COOWNER"],
-        "Status": Literal["SUCCESS", "FAILURE"],
+        "Role": RoleType,
+        "Status": ShareStatusType,
         "ShareId": str,
         "StatusMessage": str,
     },
@@ -273,13 +246,13 @@ ShareResultTypeDef = TypedDict(
 
 StorageRuleTypeTypeDef = TypedDict(
     "StorageRuleTypeTypeDef",
-    {"StorageAllocatedInBytes": int, "StorageType": Literal["UNLIMITED", "QUOTA"]},
+    {"StorageAllocatedInBytes": int, "StorageType": StorageType},
     total=False,
 )
 
 SubscriptionTypeDef = TypedDict(
     "SubscriptionTypeDef",
-    {"SubscriptionId": str, "EndPoint": str, "Protocol": Literal["HTTPS"]},
+    {"SubscriptionId": str, "EndPoint": str, "Protocol": SubscriptionProtocolType},
     total=False,
 )
 
@@ -310,14 +283,12 @@ UserTypeDef = TypedDict(
         "OrganizationId": str,
         "RootFolderId": str,
         "RecycleBinFolderId": str,
-        "Status": Literal["ACTIVE", "INACTIVE", "PENDING"],
-        "Type": Literal["USER", "ADMIN", "POWERUSER", "MINIMALUSER", "WORKSPACESUSER"],
+        "Status": UserStatusType,
+        "Type": UserType,
         "CreatedTimestamp": datetime,
         "ModifiedTimestamp": datetime,
         "TimeZoneId": str,
-        "Locale": Literal[
-            "en", "fr", "ko", "de", "es", "ja", "ru", "zh_CN", "zh_TW", "pt_BR", "default"
-        ],
+        "Locale": LocaleType,
         "Storage": "UserStorageMetadataTypeDef",
     },
     total=False,
@@ -464,12 +435,7 @@ PaginatorConfigTypeDef = TypedDict(
 )
 
 SharePrincipalTypeDef = TypedDict(
-    "SharePrincipalTypeDef",
-    {
-        "Id": str,
-        "Type": Literal["USER", "GROUP", "INVITE", "ANONYMOUS", "ORGANIZATION"],
-        "Role": Literal["VIEWER", "CONTRIBUTOR", "OWNER", "COOWNER"],
-    },
+    "SharePrincipalTypeDef", {"Id": str, "Type": PrincipalType, "Role": RoleType}
 )
 
 UpdateUserResponseTypeDef = TypedDict(
